@@ -1,9 +1,9 @@
 import unittest
+import doctest
 import os
 
 import zope.interface
 import zope.component
-import zope.testing
 import zope.component.testing
 import zope.configuration.xmlconfig
 
@@ -14,8 +14,9 @@ import chameleon.html
 import chameleon.html.tests
 import chameleon.html.language
 
-OPTIONFLAGS = (zope.testing.doctest.ELLIPSIS |
-               zope.testing.doctest.NORMALIZE_WHITESPACE)
+
+OPTIONFLAGS = (doctest.ELLIPSIS |
+               doctest.NORMALIZE_WHITESPACE)
 
 def render_xss(body, **kwargs):
     parser = chameleon.html.language.XSSTemplateParser()
@@ -38,16 +39,16 @@ def test_suite():
     chameleon.core.config.DISK_CACHE = False
     
     return unittest.TestSuite(
-        [zope.testing.doctest.DocTestSuite(
-        "chameleon.html."+doctest, optionflags=OPTIONFLAGS,
+        [doctest.DocTestSuite(
+        "chameleon.html."+dt, optionflags=OPTIONFLAGS,
         setUp=setUp, tearDown=zope.component.testing.tearDown) \
-         for doctest in testsuites] + 
+         for dt in testsuites] + 
         
-        [zope.testing.doctest.DocFileSuite(
-        doctest, optionflags=OPTIONFLAGS,
+        [doctest.DocFileSuite(
+        dt, optionflags=OPTIONFLAGS,
         globs=globs,
         setUp=setUp, tearDown=zope.component.testing.tearDown,
-        package="chameleon.html") for doctest in filesuites]
+        package="chameleon.html") for dt in filesuites]
         )
 
 if __name__ == '__main__':
